@@ -302,8 +302,7 @@ class GroupedListDiscretizer(BaseEstimator, TransformerMixin):
             to_discard = [order.get(group) for group in order]  # identification des valeur à regrouper
             to_input = [Xc[feature].isin(discarded) for discarded in to_discard]  # identification des observations à regrouper
             to_keep = [n if self.output == float else group for n, group in enumerate(order)]  # récupération du groupe dans lequel regrouper
-            arr_feature = select(to_input, to_keep, default=Xc[feature])  # grouping modalities
-            Xc[feature] = arr_feature  # storing grouped feature
+            Xc[feature] = select(to_input, to_keep, default=Xc[feature])  # grouping modalities
 
         # converting to float
         if self.output == float:
@@ -352,8 +351,7 @@ class ChainedDiscretizer(GroupedListDiscretizer):
                 # grouping rare modalities
                 to_discard = [[value for value in order.get(group) if (not value in to_keep)] for group in order]  # identifying rare values
                 to_input = [Xc[feature].isin(discarded) for discarded in to_discard]  # identifying observation to input
-                arr_feature = select(to_input, to_input, default=Xc[feature])  # regroupement des naf peu fréquents
-                Xc[feature] = arr_feature  # storing grouped feature
+                Xc[feature] = select(to_input, to_input, default=Xc[feature])  # regroupement des naf peu fréquents
                 
                 # historizing in the feature's order
                 for discarded, kept in zip(to_discard, order):
@@ -426,19 +424,16 @@ class QuantileDiscretizer(BaseEstimator, TransformerMixin):
         for n, feature in enumerate(self.features):
             if self.verbose: print(f" - [QuantileDiscretizer] Discretizing {feature} ({n+1}/{len(self.features)})")
 
-            arr_feature = Xc[feature].values  # initial feature value
-            nans = isna(arr_feature)  # keeping track of nans
+            nans = isna(Xc[feature])  # keeping track of nans
 
             # grouping values inside quantiles
-            to_input = [arr_feature <= q for q in self.quantiles.get(feature)]  # values that will be imputed
+            to_input = [Xc[feature] <= q for q in self.quantiles.get(feature)]  # values that will be imputed
             values = [[v] * len(X) for v in self.values_orders.get(feature)]  # new values to imput
-            arr_feature = select(to_input, values, default=arr_feature)  # grouping modalities
+            Xc[feature] = select(to_input, values, default=Xc[feature])  # grouping modalities
 
             # adding back nans
             if any(nans):
                 Xc.loc[nans, feature] = nan
-
-            Xc[feature] = arr_feature  # storing grouped feature
         
         return Xc
 
@@ -461,22 +456,22 @@ class ClosestDiscretizer(BaseEstimator, TransformerMixin):
         common_modalities = X[self.features].apply(
             lambda u: find_common_modalities(u, y, self.min_freq, self.values_orders.get(u.name)), 
             axis=0, result_type='expand'
-        ).T
+        ).T.to_dict()
 
         # updating the order per feature
-        self.values_orders = {f: common_modalities.get(f).get('order') for f in self.features}
+        self.values_orders = {f: common_modalities.get('order').get(f) for f in self.features}
 
         # defining the default value based on the strategy
-        self.default_values = {f: common_modalities.get(f).get(self.default) for f in self.features}
+        self.default_values = {f: common_modalities.get(self.default).get(f) for f in self.features}
 
         return self
     
     def transform(self, X, y=None):
         
         # copying dataset if requested
-        X_c = X
+        Xc = X
         if self.copy:
-            X_c = X.copy()
+            Xc = X.copy()
 
         # iterating over each feature
         for n, feature in enumerate(self.features):
@@ -486,21 +481,19 @@ class ClosestDiscretizer(BaseEstimator, TransformerMixin):
             order = self.values_orders.get(feature)
 
             # imputation des valeurs inconnues le cas échéant
-            unknowns = [value for value in X_c[feature].unique() if not any(is_equal(value, known) for known in order.values())]
+            unknowns = [value for value in Xc[feature].unique() if not any(is_equal(value, known) for known in order.values())]
             unknowns = [value for value in unknowns if notna(value)]  # suppression des NaNs
             if any(unknowns):
-                to_input = [X_c[feature] == unknown for unknown in unknowns]  # identification des valeurs à regrouper
-                arr_feature = select(to_input, [self.default_values.get(feature)], default=X_c[feature])  # regroupement des valeurs
-                X_c[feature] = arr_feature  # storing grouped feature
+                to_input = [Xc[feature] == unknown for unknown in unknowns]  # identification des valeurs à regrouper
+                Xc[feature] = select(to_input, [self.default_values.get(feature)], default=Xc[feature])  # regroupement des valeurs
                 warn(f"Unknown modalities provided for {feature}: {unknowns}")
 
             # grouping values inside groups of modalities
             to_discard = [order.get(group) for group in order]  # identification des valeur à regrouper
-            to_input = [X_c[feature].isin(discarded) for discarded in to_discard]  # identification des valeurs à regrouper
-            arr_feature = select(to_input, order, default=X_c[feature])  # regroupement des valeurs
-            X_c[feature] = arr_feature  # storing grouped feature
+            to_input = [Xc[feature].isin(discarded) for discarded in to_discard]  # identification des valeurs à regrouper
+            Xc[feature] = select(to_input, order, default=Xc[feature])  # regroupement des valeurs
 
-        return X_c
+        return Xc
 
 
 class DefaultDiscretizer(BaseEstimator, TransformerMixin):
@@ -559,19 +552,18 @@ class DefaultDiscretizer(BaseEstimator, TransformerMixin):
     def transform(self, X, y=None):
 
         # copying dataset if requested
-        X_c = X
+        Xc = X
         if self.copy:
-            X_c = X.copy()
+            Xc = X.copy()
 
         # grouping values inside groups of modalities
         for n, feature in enumerate(self.features):
             if self.verbose: print(f" - [DefaultDiscretizer] Discretizing {feature} ({n+1}/{len(self.features)})")
 
             # grouping modalities
-            arr_feature = select([~X_c[feature].isin(self.to_keep.get(feature))], [self.default_value], default=X_c[feature])
-            X_c[feature] = arr_feature  # storing grouped feature
+            Xc[feature] = select([~Xc[feature].isin(self.to_keep.get(feature))], [self.default_value], default=Xc[feature])
 
-        return X_c
+        return Xc
 
 def find_quantiles(df_feature: Series, q: int, len_df: int=None, quantiles: list=None):
     """ Découpage en quantile de la feature.
